@@ -33,7 +33,7 @@ LearnerRegrFeatureless = R6Class("LearnerRegrFeatureless", inherit = LearnerRegr
 
       super$initialize(
         id = "regr.featureless",
-        feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
+        feature_types = unname(mlr_reflections$task_feature_types),
         predict_types = c("response", "se"),
         param_set = ps,
         properties = c("missings", "importance", "selected_features"),
