@@ -199,8 +199,9 @@ test_that("empty predict set (#421)", {
   learner = lrn("classif.featureless")
   resampling = rsmp("holdout", ratio = 1)
   hout = resampling$instantiate(task)
-  model = learner$train(task, hout$train_set(1))
+  learner$train(task, hout$train_set(1))
   pred = learner$predict(task, hout$test_set(1))
+  expect_prediction(pred)
   expect_true(any(grepl("No data to predict on", learner$log$msg)))
 })
 
