@@ -8,18 +8,28 @@ test_that("resample", {
   rr = resample(task, learner, resampling, store_models = TRUE)
 
   expect_resample_result(rr)
-  expect_numeric(rr$score(msr("classif.ce"))$classif.ce, any.missing = FALSE)
+
+  scores = rr$score(msr("classif.ce"))
+  expect_list(scores$prediction, "Prediction")
+  expect_numeric(scores$classif.ce, any.missing = FALSE)
   expect_number(rr$aggregate(msr("classif.ce")))
   learners = rr$learners
   expect_different_address(learners[[1L]], learners[[2L]])
   expect_equal(uniqueN(hashes(learners)), 1L)
 
   rr$filter(2:3)
-  expect_data_table(rr$data, nrows = 2L)
-  expect_equal(rr$data$iteration, 2:3)
+  tab = as.data.table(rr)
+  expect_data_table(tab, nrows = 2L)
+  expect_data_table(tab, nrows = 2L)
+  expect_equal(tab$iteration, 2:3)
   expect_resample_result(rr, allow_incomplete = TRUE)
 })
 
+test_that("empty RR", {
+  rr = ResampleResult$new()
+  expect_resample_result(rr)
+})
+
 test_that("resample with no or multiple measures", {
   task = tsk("iris")
   learner = lrn("classif.featureless")
@@ -44,7 +54,7 @@ test_that("as_benchmark_result.ResampleResult", {
   bmr = as_benchmark_result(rr)
   expect_benchmark_result(bmr)
   expect_equal(nrow(bmr$data), nrow(rr$data))
-  expect_set_equal(bmr$data$uhash, rr$uhash)
+  expect_set_equal(bmr$uhashes, rr$uhash)
   aggr = bmr$aggregate()
   expect_data_table(aggr, nrows = 1)
   expect_set_equal(bmr$uhashes, rr$uhash)
@@ -67,9 +77,9 @@ test_that("inputs are cloned", {
   resampling$instantiate(task)
 
   rr = resample(task, learner, resampling)
-  expect_different_address(task, rr$task)
-  expect_different_address(learner, rr$data$learner[[1L]])
-  expect_different_address(resampling, rr$resampling)
+  expect_different_address(task, rr$data$data$tasks$task[[1]])
+  expect_different_address(learner, rr$data$data$learners$learner[[1]])
+  expect_different_address(resampling, rr$data$data$resamplings$resampling[[1]])
 })
 
 test_that("memory footprint", {
@@ -77,11 +87,10 @@ test_that("memory footprint", {
   learner = lrn("classif.featureless")
   resampling = rsmp("cv", folds = 3)
   rr = resample(task, learner, resampling)
-  x = as.data.table(rr)
 
-  expect_equal(uniqueN(map_chr(x$learner, address)), nrow(x))
-  expect_equal(uniqueN(map_chr(x$task, address)), 1L)
-  expect_equal(uniqueN(map_chr(x$resampling, address)), 1L)
+  expect_equal(nrow(rr$data$data$learners), 1L)
+  expect_equal(nrow(rr$data$data$tasks), 1L)
+  expect_equal(nrow(rr$data$data$resamplings), 1L)
 })
 
 test_that("predict_type is checked", {
